@@ -1,7 +1,5 @@
 import json
-import hashlib
 from tornado import web
-import base64
 import os
 from cqh_file.utils import get_base64, get_md5
 
@@ -54,6 +52,7 @@ def create_app(port, dir, timeout):
     app = web.Application(handlers=[
         ("/list", HandlerList),
         ("/download", HandlerDownload),
+        ("/files/(.*)", web.StaticFileHandler, {"path": dir}),
     ], dir=dir)
     server = app.listen(port, xheaders=True)
     loop: ioloop.IOLoop = ioloop.IOLoop.current()
